@@ -12,7 +12,7 @@
 #include <immer/flex_vector.hpp>
 #include <immer/refcount/no_refcount_policy.hpp>
 
-#include <catch2/catch.hpp>
+#include <catch2/catch_test_macros.hpp>
 
 #define IMMER_FUZZED_TRACE_ENABLE 0
 
